summaryrefslogtreecommitdiffstats
path: root/AccountValue/Form2.cs
diff options
context:
space:
mode:
Diffstat (limited to 'AccountValue/Form2.cs')
-rw-r--r--AccountValue/Form2.cs6
1 files changed, 3 insertions, 3 deletions
diff --git a/AccountValue/Form2.cs b/AccountValue/Form2.cs
index b06476a..24c4bf8 100644
--- a/AccountValue/Form2.cs
+++ b/AccountValue/Form2.cs
@@ -17,7 +17,7 @@ using System.Xml;
// #####################################################################################
// (C) 2005 - 2006 Randolph Welte randy@uni-freiburg.de#################################
//
// Bearbeitung Bohdan Dulya & Marco Haustein 2006 - 2009 ###############################
@@ -29,7 +29,7 @@ namespace AccountValue
public partial class Form2 : Form
{
private DragExtender dragExtender1;
- private String version = "1.0.0";
+ private String version = "0.5.0";
/*
*
*/
@@ -80,7 +80,7 @@ namespace AccountValue
private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
{
- MessageBox.Show("© 2006 Randolph Welte \n 2007-2009 Bohdan Dulya & Marco Haustein", "About...", MessageBoxButtons.OK, MessageBoxIcon.Information);
+ MessageBox.Show("© 2006 Randolph Welte \n 2007-2011 Bohdan Dulya, Javier Castillo & Marco Haustein", "About...", MessageBoxButtons.OK, MessageBoxIcon.Information);
}
private void versionToolStripMenuItem_Click(object sender, EventArgs e)
@@ -17,7 +17,7 @@ using System.Xml;
// (C) 2005 - 2006 Randolph Welte randy@uni-freiburg.de#################################
//
-// Bearbeitung Bohdan Dulya & Marco Haustein 2006 - 2009 ###############################
+// Bearbeitung Bohdan Dulya, Javier Castillo & Marco Haustein 2006 - 2011 ###############################
public partial class Form2 : Form